searchNodes=[{"doc":"This module is used to calculate CRC (Cyclic Redundancy Check) values for binary data. It uses NIF functions written in C to iterate over the given binary calculating the CRC checksum value. CRC implementations have been tested against these online calculators to validate their correctness to the best of our ability. https://www.lammertbies.nl/comm/info/crc-calculation.html http://www.sunshine2k.de/coding/javascript/crc/crc_js.html","ref":"CRC.html","title":"CRC","type":"module"},{"doc":"Calculate a CRC checksum for the input based on the crc params given. See CRC.crc/2 for details on valid params . This function has the parameter order reversed to allow easier use with pipelines. allowing code to be written like: Examples read_data ( ) |&gt; CRC . calculate ( :crc_16 ) |&gt; do_something ( )","ref":"CRC.html#calculate/2","title":"CRC.calculate/2","type":"function"},{"doc":"Calculates a 16-bit CCITT CRC with the given seed, seed defaults to 0xFFFF if one is not given. This CCIT method uses a 0x1021 polynomial.","ref":"CRC.html#ccitt_16/1","title":"CRC.ccitt_16/1","type":"function"},{"doc":"","ref":"CRC.html#ccitt_16/2","title":"CRC.ccitt_16/2","type":"function"},{"doc":"Calculates a 16-bit CCITT 0x1D0F CRC This CCIT method uses a 0x1021 polynomial.","ref":"CRC.html#ccitt_16_1D0F/1","title":"CRC.ccitt_16_1D0F/1","type":"function"},{"doc":"Calculates a 16-bit CCITT Kermit CRC This CCIT method uses a 0x8408 polynomial.","ref":"CRC.html#ccitt_16_kermit/1","title":"CRC.ccitt_16_kermit/1","type":"function"},{"doc":"","ref":"CRC.html#ccitt_16_kermit/2","title":"CRC.ccitt_16_kermit/2","type":"function"},{"doc":"Calculates a 16-bit CCITT XMODEM CRC This CCIT method uses a 0x1021 polynomial.","ref":"CRC.html#ccitt_16_xmodem/1","title":"CRC.ccitt_16_xmodem/1","type":"function"},{"doc":"Calculates an XOR checksum for the given binary","ref":"CRC.html#checksum_xor/1","title":"CRC.checksum_xor/1","type":"function"},{"doc":"Calculate a CRC checksum for the input based on the crc params given. params can be an atom for one of the compiled models. See CRC.list/0 for a full list or a Map with parameters to create a model at runtime. The map given should have all of the following keys: width - (unsigned integer) representation for the width of the CRC in bits poly - (unsigned integer) the polynomial used for the CRC calculation init - (unsigned integer) The initial value used when starting the calculation refin - (boolean) if the input value should be reflected. This is used for changing between endian's refout - (boolean) if the outvalue should be reflected when calculation is completed xorout - (unsigned integer) Final xor value used when completing the CRC calculation Examples %{ width : 16 , poly : 0x1021 , init : 0x00 , refin : false , refout : false , xorout : 0x00 } You can also extend one of the compiled models at runtime by creating a map with extend key set to the model you wish to extend and the keys you wish to override for that model. For example to override the initial value for the :crc_16_ccitt_false model to 0x1D0F you would pass the following Map as params: ` %{ extend : :crc_16_ccitt_false , init : 0x1D0F } ` You can learn more about CRC calculation here: https://www.sunshine2k.de/articles/coding/crc/understanding_crc.html","ref":"CRC.html#crc/2","title":"CRC.crc/2","type":"function"},{"doc":"Calculates a 16-bit ANSI CRC checksum for the provided binary","ref":"CRC.html#crc_16/1","title":"CRC.crc_16/1","type":"function"},{"doc":"Calculates a 16-bit DNP CRC","ref":"CRC.html#crc_16_dnp/1","title":"CRC.crc_16_dnp/1","type":"function"},{"doc":"Calculates a 16-bit modbus CRC","ref":"CRC.html#crc_16_modbus/1","title":"CRC.crc_16_modbus/1","type":"function"},{"doc":"Calculates a 16-bit Sick CRC","ref":"CRC.html#crc_16_sick/1","title":"CRC.crc_16_sick/1","type":"function"},{"doc":"Calculates a 32-bit CRC","ref":"CRC.html#crc_32/1","title":"CRC.crc_32/1","type":"function"},{"doc":"Calculates a 8-bit CRC with polynomial x^8+x^6+x^3+x^2+1, 0x14D. Chosen based on Koopman, et al. (0xA6 in his notation = 0x14D &gt;&gt; 1): http://www.ece.cmu.edu/ ~koopman/roses/dsn04/koopman04_crc_poly_embedded.pdf seed defaults to 0xFF if one is not given","ref":"CRC.html#crc_8/2","title":"CRC.crc_8/2","type":"function"},{"doc":"Takes a resource result from crc_update/2 and finalizes the multi-part CRC calculation.","ref":"CRC.html#crc_final/1","title":"CRC.crc_final/1","type":"function"},{"doc":"Initialize a resource to be used for doing CRC calculations. The returned resource can be used with crc/2 or crc_update/2 to calculate CRC checksums. Resource is created using the same params types that are used with crc/2 : atom's for compiled models Map with model values Map to extend a compiled model. If used with crc/2 the returned resource can be re-used multiple times, but using a map or atom for a compiled model will likely be slightly more performant. When using with crc_update/2 a new resource will be returned with every call that should be used to continue the calculation.","ref":"CRC.html#crc_init/1","title":"CRC.crc_init/1","type":"function"},{"doc":"Begins or continues a multi-part CRC calculation. Takes a resource from result of crc_init/1 or previous crc_update/2 call, and binary input , returns a new resource to be used to continue or finalize the CRC calculation.","ref":"CRC.html#crc_update/2","title":"CRC.crc_update/2","type":"function"},{"doc":"Returns a list of all the compiled CRC models.","ref":"CRC.html#list/0","title":"CRC.list/0","type":"function"},{"doc":"Returns a list of all compiled CRC Models that match the filter given. Filter is compiled into a regular expression and matched against the model name and description.","ref":"CRC.html#list/1","title":"CRC.list/1","type":"function"},{"doc":"","ref":"CRC.Model.html","title":"CRC.Model","type":"module"},{"doc":"","ref":"CRC.Model.html#decode/1","title":"CRC.Model.decode/1","type":"function"},{"doc":"","ref":"CRC.Model.html#decode_file/1","title":"CRC.Model.decode_file/1","type":"function"},{"doc":"","ref":"CRC.Model.html#decode_list/1","title":"CRC.Model.decode_list/1","type":"function"},{"doc":"","ref":"CRC.Model.html#dump_code/1","title":"CRC.Model.dump_code/1","type":"function"},{"doc":"","ref":"CRC.Model.html#gen_code/1","title":"CRC.Model.gen_code/1","type":"function"},{"doc":"","ref":"CRC.Model.html#gen_stubs/1","title":"CRC.Model.gen_stubs/1","type":"function"},{"doc":"","ref":"CRC.Model.html#gen_tables/1","title":"CRC.Model.gen_tables/1","type":"function"},{"doc":"","ref":"CRC.Model.html#t:t/0","title":"CRC.Model.t/0","type":"type"},{"doc":"Changelog All notable changes to this project will be documented in this file. The format is based on Keep a Changelog , and this project adheres to Semantic Versioning .","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Fix elixir compiler warnings #47","ref":"changelog.html#v0-10-5-2023-06-23","title":"Changelog - v0.10.5 - 2023-06-23","type":"extras"},{"doc":"Fix issue with the priv directory not existing when running the Windows Makefile","ref":"changelog.html#v0-10-4-2022-01-20","title":"Changelog - v0.10.4 - 2022-01-20","type":"extras"},{"doc":"Updated Makefile to append (+=) to environment variables instead of conditionally setting them with ?= to fix an issue where LDFLAGS was not set correctly. See #42","ref":"changelog.html#v0-10-3-2021-12-17","title":"Changelog - v0.10.3 - 2021-12-17","type":"extras"},{"doc":"fix compiling on non x86_64 architecture (M1 mac)","ref":"changelog.html#v0-10-2-2021-07-21","title":"Changelog - v0.10.2 - 2021-07-21","type":"extras"},{"doc":"Removed usage of ERL_INTERFACE_INCLUDE_DIR , it was removed in OTP 23","ref":"changelog.html#v0-10-1-2020-06-12","title":"Changelog - v0.10.1 - 2020-06-12","type":"extras"},{"doc":"Added Change build path to use MIX_APP_PATH if available. This should improve compilation for multiple nerves targets.","ref":"changelog.html#v0-10-0-2020-01-31","title":"Changelog - v0.10.0 - 2020-01-31","type":"extras"},{"doc":"Fixes Fixed GCC warning implicit declaration of strnlen on GNU/Linux","ref":"changelog.html#v0-9-2-2019-04-09","title":"Changelog - v0.9.2 - 2019-04-09","type":"extras"},{"doc":"Fixes Removed files from Windows Makefile to fix compiling on Windows.","ref":"changelog.html#v0-9-1-2018-03-09","title":"Changelog - v0.9.1 - 2018-03-09","type":"extras"},{"doc":"Added CRC.calculate/2 generic calculate function that takes the input as first parameter. This is a copy of CRC.crc/2 but should allow easier transition from the legacy model functions ie CRC.crc_16 etc. Many README and Documentation tweaks / improvements.","ref":"changelog.html#v0-9-0-2018-03-09","title":"Changelog - v0.9.0 - 2018-03-09","type":"extras"},{"doc":"Added CRC module docs Docs for generic CRC.crc functions Changes Migrated erlang model specific functions to use crc_fast instead of model specific NIFs Removed model specific NIFs Moved model specific functions from CRC to CRC.Legacy Removed redundant tests","ref":"changelog.html#v0-8-3-2018-02-09","title":"Changelog - v0.8.3 - 2018-02-09","type":"extras"},{"doc":"Fixes Fixed cross-compile settings Removed compile-time reference to NIF","ref":"changelog.html#v0-8-2-2018-01-17","title":"Changelog - v0.8.2 - 2018-01-17","type":"extras"},{"doc":"Fixes Restored Windows build support #21 Added CRC.list/0 &amp; CRC.list/1 functions to get full list of pre-defined models","ref":"changelog.html#v0-8-1-2018-01-11","title":"Changelog - v0.8.1 - 2018-01-11","type":"extras"},{"doc":"Added Generic CRC calculation NIFs CRC.crc/2 , CRC.crc_init/1 , CRC.crc_update/2 , CRC.crc_final/1 PYCRC property tests to TravisCI build","ref":"changelog.html#v0-8-0-2017-12-22","title":"Changelog - v0.8.0 - 2017-12-22","type":"extras"},{"doc":"Fixes Removed compiled NIF files from release #16","ref":"changelog.html#v0-7-1-2017-11-29","title":"Changelog - v0.7.1 - 2017-11-29","type":"extras"},{"doc":"Added Timeslice reduction counting to NIFs, allowing NIF functions to play nice with the BEAM Scheduler Erlang support &amp; rebar configs NIF based XOR checksum","ref":"changelog.html#v0-7-0-2017-10-19","title":"Changelog - v0.7.0 - 2017-10-19","type":"extras"},{"doc":"Added CRC-16 Kermit Added TravisCI","ref":"changelog.html#v0-6-0-2017-08-28","title":"Changelog - v0.6.0 - 2017-08-28","type":"extras"},{"doc":"The MIT License (MIT) Copyright (c) 2015 Rodney Norris Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"License","type":"extras"},{"doc":"CRC This module is used to calculate CRC (Cyclic Redundancy Check) values for binary data. It uses NIF functions written in C to iterate over the given binary calculating the CRC checksum value. The NIFs are written to report their time slice usage and will not interfere with the schedulers.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"Elixir Add :crc to your list of dependencies in mix.exs : def deps do [ { :crc , &quot;~&gt; 0.10&quot; } ] end Erlang Add crc to your rebar.config : { deps , [ { crc , &quot;0.10.5&quot; } ] } . Or erlang.mk : dep_crc = hex 0.10 . 5","ref":"readme.html#installation","title":"Overview - Installation","type":"extras"},{"doc":"Run CRC.list/0 to get a full list of all pre-defined models or CRC.list/1 with a filter to search for a pre-defined model.","ref":"readme.html#supported-algorithms-models","title":"Overview - Supported algorithms (models)","type":"extras"},{"doc":"To calculate a CRC-16 X-Modem checksum for the binary &lt;&lt;1,2,3,4,5,4,3,2,1&gt;&gt; using the pre-defined model: iex&gt; CRC . crc ( :crc_16_xmodem , &lt;&lt; 1 , 2 , 3 , 4 , 5 , 4 , 3 , 2 , 1 &gt;&gt; ) 31763 iex&gt; CRC . calculate ( &lt;&lt; 1 , 2 , 3 , 4 , 5 , 4 , 3 , 2 , 1 &gt;&gt; , :crc_16_xmodem ) 31763 Or you can create a model at runtime, this can be done with a map: iex&gt; CRC . crc ( %{ width : 16 , poly : 0x1021 , init : 0x00 , refin : false , refout : false , xorout : 0x00 } , &lt;&lt; 1 , 2 , 3 , 4 , 5 , 4 , 3 , 2 , 1 &gt;&gt; ) 31763 iex&gt; CRC . calculate ( &lt;&lt; 1 , 2 , 3 , 4 , 5 , 4 , 3 , 2 , 1 &gt;&gt; , %{ width : 16 , poly : 0x1021 , init : 0x00 , refin : false , refout : false , xorout : 0x00 } ) 31763 Or you can extend one of the pre-defined models: iex&gt; CRC . crc ( %{ extend : :crc_16_xmodem , init : 0x00 , } , &lt;&lt; 1 , 2 , 3 , 4 , 5 , 4 , 3 , 2 , 1 &gt;&gt; ) 31763 CRC.crc_init/1 is used to create a resource and be used to do partial updates to a calculation that is then finalized later: iex&gt; resource = CRC . crc_init ( :crc_16_xmodem ) # Reference &lt; x . x . x . x &gt; iex&gt; resource2 = CRC . crc_update ( resource , &lt;&lt; 1 , 2 , 3 , 4 , 5 &gt;&gt; ) # Reference &lt; y . y . y . y &gt; iex&gt; resource3 = CRC . crc_update ( resource2 , &lt;&lt; 4 , 3 , 2 , 1 &gt;&gt; ) # Reference &lt; z . z . z . z &gt; iex&gt; CRC . crc_final ( resource3 ) 31763 This could be useful to calculate a CRC for a larger binary that you are receiving asynchronously.","ref":"readme.html#usage","title":"Overview - Usage","type":"extras"},{"doc":"CRC implementations have been tested against these online calculators to validate their correctness to the best of our ability. https://www.lammertbies.nl/comm/info/crc-calculation.html http://www.sunshine2k.de/coding/javascript/crc/crc_js.html There are also two property tests that can use PyCRC or CRC RevEng if installed and configured locally. $ export PYCRC_BIN=~/pycrc-0.9.1/pycrc.py $ export REVENG_BIN=~/reveng-1.5.2/reveng $ mix test PyCRC is used as a part of the TravisCI test suite.","ref":"readme.html#tests","title":"Overview - Tests","type":"extras"},{"doc":"Copyright (c) 2015 Rodney Norris CRC is released under the MIT License. See the LICENSE.md file for further details.","ref":"readme.html#copyright-and-license","title":"Overview - Copyright and License","type":"extras"}]